@@ -30,9 +30,7 @@ for my $n (1 .. $d->bars) {
     two();
 }
 
-# $d->write;
-# $d->play_with_timidity;
-$d->play_with_fluidsynth;
+$d->write;
 
 sub one {
     $d->note($dura, $cymbal, $d->kick);
